#
# spec file for package opencv
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname lib%{name}
%define soname 3_3
# disabled by default as many fail
%bcond_with tests
%bcond_without qt5
%bcond_without ffmpeg
%bcond_without python2
%bcond_without python3
Name:           opencv
Version:        3.3.1
Release:        lp152.7.9
Summary:        Collection of algorithms for computer vision
# GPL-2.9 AND Apache-2.0 files are in 3rdparty/ittnotify which is not build
License:        BSD-3-Clause AND GPL-2.0 AND Apache-2.0
Group:          Development/Libraries/C and C++
Url:            http://opencv.org/
Source0:        https://github.com/opencv/opencv/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# This is the FACE module from the opencv_contrib package. Packaged separately to prevent too much usntable modules
Source1:        opencv_contrib_face-3.1.0.tar.bz2
# PATCH-FIX-OPENCSUSE opencv-gles.patch -- Make sure PERSPECTIVE_CORRECTION_HINT is validated first, https://github.com/opencv/opencv/issues/9171
Patch1:         opencv-gles.patch
# PATCH-FIX-OPENSUSE opencv-build-compare.patch -- avoid republish if some random external version number changes
Patch8:         opencv-build-compare.patch
# PATCH-FIX-OPENSUSE 0001-Do-not-include-glx.h-when-using-GLES.patch -- Fix build error on 32bit ARM, due to incompatible pointer types, https://github.com/opencv/opencv/issues/9171
Patch11:        0001-Do-not-include-glx.h-when-using-GLES.patch
# PATCH-FIX-OPENSUSE fix_processor_detection_for_32bit_on_64bit.patch -- Fix CPU detection for 32bit build on qemu-system-aarch64
Patch12:        fix_processor_detection_for_32bit_on_64bit.patch
# PATCH-FIX-UPSTREAM opencv-imgproc-fix-bounds-check.patch -- imgproc(hdr): fix bounds check in HdrDecoder::checkSignature()
Patch13:        opencv-imgproc-fix-bounds-check.patch
# PATCH-FIX-UPSTREAM opencv-cmake-rel-deb-info.patch boo#1154091 mgorse@suse.com -- rework MAP_IMPORTED_CONFIG to prevent unintended build failures.
Patch14:        opencv-cmake-rel-deb-info.patch
# PATCH-FIX-UPSTREAM opencv-check-macros.patch boo#1144352 boo#1144348 mgorse@suse.com -- add "check" macros.
Patch15:        opencv-check-macros.patch
# PATCH-FIX-UPSTREAM cve-2019-14491.patch boo#1144352 boo#1144348 mgorse@suse.com -- objdetect: validate feature rectangle on reading.
Patch16:        CVE-2019-14491.patch
# PATCH-FIX-UPSTREAM CVE-2019-15939.patch boo#1149742 mgorse@suse.com -- add input check in HOG detector.
Patch17:        CVE-2019-15939.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  libeigen3-devel
BuildRequires:  libjasper-devel
BuildRequires:  libjpeg-devel
BuildRequires:  openblas-devel
BuildRequires:  pkgconfig
BuildRequires:  tbb-devel
BuildRequires:  unzip
BuildRequires:  pkgconfig(IlmBase)
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(libdc1394-2)
BuildRequires:  pkgconfig(libgphoto2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(libv4lconvert)
BuildRequires:  pkgconfig(zlib)
Provides:       opencv-qt5
Obsoletes:      opencv-qt5
%if %{with python2}
BuildRequires:  pkgconfig(python)
%if 0%{?suse_version} > 1325
BuildRequires:  python2-numpy-devel
%else
BuildRequires:  python-numpy-devel
%endif
%endif
%if %{with python3}
BuildRequires:  python3-numpy-devel
BuildRequires:  pkgconfig(python3)
%endif
%if %{with qt5}
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Gui) >= 5.2.0
BuildRequires:  pkgconfig(Qt5OpenGL) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Test) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2.0
%else
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(QtOpenGL)
BuildRequires:  pkgconfig(QtTest)
%endif
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
%endif

%description
OpenCV means Intel® Open Source Computer Vision Library. It is a collection of C
functions and a few C++ classes that implement some popular Image Processing and
Computer Vision algorithms.

%package -n %{libname}%{soname}
Summary:        Libraries to use OpenCV computer vision
License:        BSD-3-Clause
Group:          System/Libraries

%description -n %{libname}%{soname}
The Open Computer Vision Library is a collection of algorithms and sample code
for various computer vision problems. The library is compatible with IPL and
utilizes Intel Integrated Performance Primitives for better performance.

%package devel
Summary:        Development files for using the OpenCV library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{soname} = %{version}
Requires:       %{name} = %{version}
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glu)
Requires:       pkgconfig(ice)
Requires:       pkgconfig(sm)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xext)
Provides:       %{name}-qt5-devel
Obsoletes:      %{name}-qt5-devel

%description devel
This package contains the OpenCV C/C++ library and header files, as well as
documentation. It should be installed if you want to develop programs that will
use the OpenCV library.

%package -n python2-%{name}
Summary:        Python 2 bindings for apps which use OpenCV
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Provides:       python-%{name} = %{version}-%{release}
Obsoletes:      python-%{name} < %{version}-%{release}
Provides:       python-%{name}-qt5
Obsoletes:      python-%{name}-qt5

%description -n python2-%{name}
This package contains Python 2 bindings for the OpenCV library.

%package -n python3-%{name}
Summary:        Python 3 bindings for apps which use OpenCV
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Provides:       python3-%{name}-qt5
Obsoletes:      python3-%{name}-qt5

%description -n python3-%{name}
This package contains Python 3 bindings for the OpenCV library.

%package doc
Summary:        Documentation and examples for OpenCV
License:        BSD-3-Clause
Group:          Documentation/Other
Recommends:     python
# Since this package also contains examples that need -devel to be compiled
Suggests:       %{name}-devel
Provides:       %{name}-qt5-doc
Obsoletes:      %{name}-qt5-doc

%description doc
This package contains the documentation and examples for the OpenCV library.

%prep
%setup -q -a 1
%autopatch -p1

# Remove Windows specific files
rm -f doc/packaging.txt

%build
# Dynamic dispatch: https://github.com/opencv/opencv/wiki/CPU-optimizations-build-options
# x86: disable SSE on 32bit, do not dispatch AVX and later - SSE3
#      is the highest extension available on any non-64bit x86 CPU
# ARM: ARMv6, e.g. RPi1, only has VFPv2
%cmake \
%if %{with tests}
      -DBUILD_TESTS=ON \
%endif
      -DINSTALL_C_EXAMPLES=ON \
      -DINSTALL_PYTHON_EXAMPLES=ON \
      -DENABLE_OMIT_FRAME_POINTER=OFF \
      -DWITH_QT=ON \
      -DWITH_OPENGL=ON \
      -DWITH_UNICAP=ON \
      -DWITH_XINE=ON \
      -DWITH_IPP=OFF \
      -DWITH_TBB=ON \
%ifarch %{ix86}
      -DCPU_BASELINE_DISABLE=SSE \
      -DCPU_DISPATCH=SSE,SSE2,SSE3 \
%endif
%ifarch x86_64
      -DCPU_BASELINE=SSE2 \
      -DCPU_DISPATCH=SSE3,SSE4_1,SSE4_2,AVX,FP16,AVX2 \
%endif
%ifarch %{arm}
%ifarch armv7l armv7hl
      -DCPU_BASELINE=VFPV3 \
      -DCPU_DISPATCH=NEON \
%else
      -DCPU_BASELINE_DISABLE=NEON,VFPV3 \
%endif
%endif
%ifarch aarch64
      -DCPU_BASELINE=NEON \
      -DCPU_DISPATCH=FP16 \
%endif

make %{?_smp_mflags} VERBOSE=1

%check
%if %{with tests}
export LD_LIBRARY_PATH=$(pwd)/build/lib:$LD_LIBRARY_PATH
%ctest
%endif

%install
%cmake_install
mkdir -p %{buildroot}%{_docdir}/%{name}-doc
mv %{buildroot}%{_datadir}/OpenCV/samples %{buildroot}%{_docdir}/%{name}-doc/examples

# Fix rpmlint warning "doc-file-dependency"
chmod 644 %{buildroot}%{_docdir}/%{name}-doc/examples/python/*.py

%fdupes -s %{buildroot}%{_docdir}/%{name}-doc/examples
%fdupes -s %{buildroot}%{_includedir}

%post -n %{libname}%{soname} -p /sbin/ldconfig
%postun -n %{libname}%{soname} -p /sbin/ldconfig

%files
%{_bindir}/opencv_*
%{_datadir}/OpenCV
%exclude %{_datadir}/OpenCV/OpenCVConfig*.cmake

%files -n %{libname}%{soname}
%{_libdir}/lib*.so.*

%files devel
%{_includedir}/opencv/
%{_includedir}/opencv2/
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/opencv.pc
%{_datadir}/OpenCV/OpenCVConfig*.cmake

%if %{with python2}
%files -n python2-%{name}
%{python_sitearch}/cv2.so
%endif

%if %{with python3}
%files -n python3-%{name}
%{python3_sitearch}/cv2.%{py3_soflags}.so
%endif

%files doc
%{_docdir}/%{name}-doc/

%changelog
* Thu Oct 17 2019 Michael Gorse <mgorse@suse.com>
- Add CVE-2019-15939.patch: add input check in HOG detector
  (boo#1149742 CVE-2019-15939).
* Wed Oct 16 2019 Michael Gorse <mgorse@suse.com>
- Add opencv-cmake-rel-deb-info.patch: rework MAP_IMPORTED_CONFIG
  to prevent unintended build failures (boo#1154091).
- Add opencv-check-macros.patch: Add "check" macros (boo#1144352
  boo#1144348).
- Add CVE-2019-14491.patch: objdetect: validate feature rectangle
  when reading (boo#1144352 boo#1144348 CVE-2019-14491
  CVE-2019-14492).
* Mon May 21 2018 qzheng@suse.com
- Add opencv-imgproc-fix-bounds-check.patch:
  make backport from commit 4ca89db to fix imgproc(hdr)
  bounds check in HdrDecoder::checkSignature ( bsc#1074312,
  CVE-2017-18009 ).
* Mon Jan  8 2018 tchvatal@suse.com
- Add conditionals for python2 and python3 to allow us enabling
  only desired python variants when needed
- Do not depend on sphinx as py2 and py3 seem to collide there
* Sat Nov 25 2017 stefan.bruens@rwth-aachen.de
- Readd opencv-gles.patch, it is *not* included upstream; otherwise
  build breaks on all GLES Qt5 platforms (armv6l, armv7l, aarch64)
- add fix_processor_detection_for_32bit_on_64bit.patch
- Correctly set optimizations and dynamic dispatch on ARM, use
  OpenCV 3.3 syntax on x86.
* Mon Nov 13 2017 mpluskal@suse.com
- Update licensing information
* Wed Nov  8 2017 ecsos@opensuse.org
- change requires of python-numpy-devel to build in Leap and
  to not break factory in future
* Sat Nov  4 2017 ecsos@opensuse.org
- fix build error/unresolvable for Leap 42.2 and 42.3
* Fri Nov  3 2017 mpluskal@suse.com
- Update to version 3.3.1:
  * Lots of various bugfixes
- Update source url
* Thu Nov  2 2017 mpluskal@suse.com
- Rename python subpackage to python2
- Do not explicitly require python-base for python subpackages
* Mon Oct  9 2017 kah0922@gmail.com
- Update to 3.3
- Dropped obsolete patches
  * opencv-gcc6-fix-pch-support-PR8345.patch
  * opencv-gles.patch
- Updated opencv-build-compare.patch
* Sat Jul 15 2017 stefan.bruens@rwth-aachen.de
- Add 0001-Do-not-include-glx.h-when-using-GLES.patch
  Fix build for 32bit ARM, including both GLES and desktop GL headers
  causes incompatible pointer type errors
* Mon Jun  5 2017 tchvatal@suse.com
- Add conditional for the qt5/qt4 integration
  * This is used only for gui tools, library is not affected
- Add provides/obsoletes for the qt5 packages to allow migration
- Drop patch opencv-qt5-sobump.diff
  * Used only by the obsoleted qt5 variant
* Mon Jun  5 2017 tchvatal@suse.com
- Cleanup a bit with spec-cleaner
- Use %%cmake macros
- Remove the conditions that are not really needed
- Add tests conditional disabled by default
  * Many tests fail and there are missing testdata
- Switch to pkgconfig style dependencies
* Sun May 28 2017 stefan.bruens@rwth-aachen.de
- Update to OpenCV 3.2.0
  - Results from 11 GSoC 2016 projects have been submitted to the library:
    + sinusoidal patterns for structured light and phase unwrapping module
    [Ambroise Moreau (Delia Passalacqua)]
    + DIS optical flow (excellent dense optical flow algorithm that is both
    significantly better and significantly faster than Farneback’s algorithm –
    our baseline), and learning-based color constancy algorithms implementation
    [Alexander Bokov (Maksim Shabunin)]
    + CNN based tracking algorithm (GOTURN) [Tyan Vladimir (Antonella Cascitelli)]
    + PCAFlow and Global Patch Collider algorithms implementation
    [Vladislav Samsonov (Ethan Rublee)]
    + Multi-language OpenCV Tutorials in Python, C++ and Java
    [João Cartucho (Vincent Rabaud)]
    + New camera model and parallel processing for stitching pipeline
    [Jiri Horner (Bo Li)]
    + Optimizations and improvements of dnn module
    [Vitaliy Lyudvichenko (Anatoly Baksheev)]
    + Base64 and JSON support for file storage. Use names like
    “myfilestorage.xml?base64” when writing file storage to store big chunks of
    numerical data in base64-encoded form.  [Iric Wu (Vadim Pisarevsky)]
    + tiny_dnn improvements and integration
    [Edgar Riba (Manuele Tamburrano, Stefano Fabri)]
    + Quantization and semantic saliency detection with tiny_dnn
    [Yida Wang (Manuele Tamburrano, Stefano Fabri)]
    + Word-spotting CNN based algorithm
    [Anguelos Nicolaou (Lluis Gomez)]
  - Contributions besides GSoC:
    + Greatly improved and accelerated dnn module in opencv_contrib:
  - Many new layers, including deconvolution, LSTM etc.
  - Support for semantic segmentation and SSD networks with samples.
  - TensorFlow importer + sample that runs Inception net by Google.
    + More image formats and camera backends supported
    + Interactive camera calibration app
    + Multiple algorithms implemented in opencv_contrib
    + Supported latest OSes, including Ubuntu 16.04 LTS and OSX 10.12
    + Lot’s of optimizations for IA and ARM archs using parallelism, vector
    instructions and new OpenCL kernels.
    + OpenCV now can use vendor-provided OpenVX and LAPACK/BLAS (including Intel MKL,
    Apple’s Accelerate, OpenBLAS and Atlas) for acceleration
- Refreshed opencv-build-compare.patch
- Dropped upstream opencv-gcc5.patch
- Replace opencv-gcc6-disable-pch.patch with upstream patch
  opencv-gcc6-fix-pch-support-PR8345.patch
- Enable TBB support (C++ threading library)
- Add dependency on openBLAS
* Thu Jul 21 2016 olaf@aepfle.de
- Enable ffmpeg support unconditional
* Tue Jun  7 2016 dimstar@opensuse.org
- In case we build using GCC6 (or newer), add -mlra to CFLAGS to
  workaround gcc bug
  https://gcc.gnu.org/bugzilla/show_bug.cgi?id=71294.
* Wed May 25 2016 martin.liska@suse.com
- Apply upstream patch opencv-gcc6-disable-pch.patch to disable
  PCH for GCC6.
* Mon Mar 21 2016 toddrme2178@gmail.com
- Test for python versions greater than or equal to the current
  version.
* Wed Mar  9 2016 toddrme2178@gmail.com
- Add python 3 support
* Thu Mar  3 2016 tittiatcoke@gmail.com
- Added opencv_contrib_face-3.1.0.tar.bz2
  * This tarball is created to take only the face module from the
    contrib package. The Face module is required by libkface, which
    in its turn is required by digikam.
* Sun Feb 28 2016 joerg.lorenzen@ki.tng.de
- Added _constraints file to avoid random failures on small workers
  (at least for builds on PMBS)
* Sat Feb 27 2016 joerg.lorenzen@ki.tng.de
- Update to OpenCV 3.1.0
  - A lot of new functionality has been introduced during Google
    Summer of Code 2015:
    + “Omnidirectional Cameras Calibration and Stereo 3D
    Reconstruction” – opencv_contrib/ccalib module
    (Baisheng Lai, Bo Li)
    + “Structure From Motion” – opencv_contrib/sfm module
    (Edgar Riba, Vincent Rabaud)
    + “Improved Deformable Part-based Models” – opencv_contrib/dpm
    module (Jiaolong Xu, Bence Magyar)
    + “Real-time Multi-object Tracking using Kernelized Correlation
    Filter” – opencv_contrib/tracking module
    (Laksono Kurnianggoro, Fernando J. Iglesias Garcia)
    + “Improved and expanded Scene Text Detection” –
    opencv_contrib/text module (Lluis Gomez, Vadim Pisarevsky)
    + “Stereo correspondence improvements” – opencv_contrib/stereo
    module (Mircea Paul Muresan, Sergei Nosov)
    + “Structured-Light System Calibration” –
    opencv_contrib/structured_light (Roberta Ravanelli,
    Delia Passalacqua, Stefano Fabri, Claudia Rapuano)
    + “Chessboard+ArUco for camera calibration” –
    opencv_contrib/aruco (Sergio Garrido, Prasanna, Gary Bradski)
    + “Implementation of universal interface for deep neural
    network frameworks” – opencv_contrib/dnn module
    (Vitaliy Lyudvichenko, Anatoly Baksheev)
    + “Recent advances in edge-aware filtering, improved SGBM
    stereo algorithm” – opencv/calib3d and opencv_contrib/ximgproc
    (Alexander Bokov, Maksim Shabunin)
    + “Improved ICF detector, waldboost implementation” –
    opencv_contrib/xobjdetect (Vlad Shakhuro, Alexander Bovyrin)
    + “Multi-target TLD tracking” – opencv_contrib/tracking module
    (Vladimir Tyan, Antonella Cascitelli)
    + “3D pose estimation using CNNs” – opencv_contrib/cnn_3dobj
    (Yida Wang, Manuele Tamburrano, Stefano Fabri)
  - Many great contributions made by the community, such as:
    + Support for HDF5 format
    + New/Improved optical flow algorithms
    + Multiple new image processing algorithms for filtering,
    segmentation and feature detection
    + Superpixel segmentation and much more
  - IPPICV is now based on IPP 9.0.1, which should make OpenCV
    even faster on modern Intel chips
  - opencv_contrib modules can now be included into the
    opencv2.framework for iOS
  - Newest operating systems are supported: Windows 10 and
    OSX 10.11 (Visual Studio 2015 and XCode 7.1.1)
  - Interoperability between T-API and OpenCL, OpenGL, DirectX and
    Video Acceleration API on Linux, as well as Android 5 camera.
  - HAL (Hardware Acceleration Layer) module functionality has been
    moved into corresponding basic modules; the HAL replacement
    mechanism has been implemented along with the examples
- Removed improve-sphinx-search.diff, opencv-altivec-vector.patch,
  opencv-pkgconfig.patch and opencv-samples.patch, fixed upstream.
- Fixed opencv-qt5-sobump.diff, opencv-build-compare.patch,
  opencv-gcc5.patch and opencv-gles.patch.
- Version OpenCV 3.0.0
  + ~1500 patches, submitted as PR @ github. All our patches go
    the same route.
  + opencv_contrib (http://github.com/itseez/opencv_contrib)
    repository has been added. A lot of new functionality is there
    already! opencv_contrib is only compatible with 3.0/master,
    not 2.4. Clone the repository and use “cmake …
  - D OPENCV_EXTRA_MODULES_PATH=<path_to opencv_contrib/modules> …”
    to build opencv and opencv_contrib together.
  + a subset of Intel IPP (IPPCV) is given to us and our users free
    of charge, free of licensing fees, for commercial and
    non-commerical use. It’s used by default in x86 and x64 builds
    on Windows, Linux and Mac.
  + T-API (transparent API) has been introduced, this is transparent
    GPU acceleration layer using OpenCL. It does not add any
    compile-time or runtime dependency of OpenCL. When OpenCL is
    available, it’s detected and used, but it can be disabled at
    compile time or at runtime. It covers ~100 OpenCV functions.
    This work has been done by contract and with generous support
    from AMD and Intel companies.
  + ~40 OpenCV functions have been accelerated using NEON intrinsics
    and because these are mostly basic functions, some higher-level
    functions got accelerated as well.
  + There is also new OpenCV HAL layer that will simplifies creation
    of NEON-optimized code and that should form a base for the
    open-source and proprietary OpenCV accelerators.
  + The documentation is now in Doxygen: http://docs.opencv.org/master/
  + We cleaned up API of many high-level algorithms from features2d,
    calib3d, objdetect etc. They now follow the uniform
    “abstract interface – hidden implementation” pattern and make
    extensive use of smart pointers (Ptr<>).
  + Greatly improved and extended Python & Java bindings (also,
    see below on the Python bindings), newly introduced Matlab
    bindings (still in alpha stage).
  + Improved Android support – now OpenCV Manager is in Java and
    supports both 2.4 and 3.0.
  + Greatly improved WinRT support, including video capturing and
    multi-threading capabilities. Thanks for Microsoft team for this!
  + Big thanks to Google who funded several successive GSoC programs
    and let OpenCV in. The results of many successful GSoC 2013 and
    2014 projects have been integrated in opencv 3.0 and
    opencv_contrib (earlier results are also available in
    OpenCV 2.4.x). We can name:
  - text detection
  - many computational photography algorithms (HDR, inpainting,
    edge-aware filters, superpixels, …)
  - tracking and optical flow algorithms
  - new features, including line descriptors, KAZE/AKAZE
  - general use optimization (hill climbing, linear programming)
  - greatly improved Python support, including Python 3.0 support,
    many new tutorials & samples on how to use OpenCV with Python.
  - 2d shape matching module and 3d surface matching module
  - RGB-D module
  - VTK-based 3D visualization module
  - etc.
  + Besides Google, we enjoyed (and hope that you will enjoy too)
    many useful contributions from community, like:
  - biologically inspired vision module
  - DAISY features, LATCH descriptor, improved BRIEF
  - image registration module
  - etc.
* Fri Jan 22 2016 olaf@aepfle.de
- Reduce build-compare noise
  opencv-build-compare.patch
* Wed Dec 23 2015 alarrosa@suse.com
- Remove BuildRequirement for python-sphinx in SLE12, since it's
  not available there and it's not a mandatory requirement.
* Wed Dec  2 2015 ohering@suse.de
- Reduce differences between two spec files
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Fri Jul 24 2015 mlin@suse.com
- Update improve-sphinx-search.diff for new python-Sphinx(1.3.1)
  * now that sphinx-build disallow executing without arguments and
    give you "Insufficient arguments" error, use "sphinx-build -h"
    instead
  * the default usages output ie. sphinx-build(or --help) no longer
    are standard error but standard output, drop OUTPUT_QUIET and
    add OUTPUT_VARIABLE throws the output to SPHINX_OUTPUT as well
* Wed Apr 29 2015 coolo@suse.com
- support gcc 5 (i.e. gcc versions without minor version):
  opencv-gcc5.patch
* Wed Apr 29 2015 coolo@suse.com
- Update to OpenCV 2.4.11 - can't find NEWS or Changelog
  merely collecting bug fixes while 3.0 is in the making, 2.4.11
  didn't even make it on their web page, it's only on download
  server
- remove opencv-underlinking.patch as obsolete
- remove upstream patch bomb_commit_gstreamer-1x-support.patch
- commenting out opencv-pkgconfig.patch - possibly it requires a rebase,
  but the problem it tries to solve is unclear
* Mon Jan 26 2015 tittiatcoke@gmail.com
- Add specific buildrequires for libpng15, so that we are
  building against the system provided libpng.
* Tue May 13 2014 koprok@gmail.com
- Update to OpenCV 2.4.9
  More info at:
  http://opencv.org/opencv-2-4-9-is-out.html
  The brief list of changes:
  * new 3D visualization module ‘viz’;
  * performance fixes in ‘ocl’ module;
  * fixes in Android Camera;
  * improved CUDA support for mobile platforms;
  * bugfixes from community;
  * 55 reported bugs have been closed;
  * 156 pull requests have been merged.
* Sun Apr  6 2014 tittiatcoke@gmail.com
- Drop the BuildRequires on libucil and libunicap for Factory. This
  stops us from getting ride of Gstreamer 0.10 and besides these two
  libraries seem to be unmaintained upstream as that the latest
  actions are from 2010
* Thu Apr  3 2014 tittiatcoke@gmail.com
- Add upstream patch (3.0 version) to support Gstreamer 1.x
  * bomb_commit_gstreamer-1x-support.patch
* Thu Mar 13 2014 tchvatal@suse.com
- Upstream now provides tarballs with source only as git tags
  from github so update Source0 path.
* Wed Mar 12 2014 tchvatal@suse.com
- Add requires on various X extensions linked to opencv_ts module.
  As those are present in the .pc file we need it anyway.
* Sun Jan 19 2014 koprok@gmail.com
- Update to OpenCV 2.4.8
  More info at:
  http://opencv.org/opencv-2-4-8.html
  The brief list of changes:
  * NVidia CUDA support on Android devices with CUDA capable SoC and
    CUDA sample;
  * Concurrent kernel execution and user defined context support for
    OpenCL;
  * Integration with Intel Perceptual SDK and new depth sensors support
    for Windows;
  * 32 reported bugs have been closed;
  * 139 pull requests have been merged;
* Thu Jan 16 2014 dvlaeev@suse.com
- Fix build with altivec:
  opencv-altivec-vector.patch
* Sun Dec  1 2013 hrvoje.senjan@gmail.com
- Added opencv-pkgconfig.patch: make sure to provide link flags in
  OpenCV pc file (bnc#853036)
* Tue Nov 12 2013 hrvoje.senjan@gmail.com
- Update to OpenCV 2.4.7
  More info at:
  http://opencv.org/opencv-2-4-7-is-out.html
  The brief list of changes:
  * dynamic OpenCL runtime loading, setting default OpenCL device
    via env var, many bug-fixes and some new optimization with OpenCL
  * bug-fixes and new optimizations in CUDA stuff
  * latest NDK and Android OS support, Native Android Camera tuning
  * minor fixes, XAML sample and MS Certification compatibility
    in WinRT stuff
  * 382 pull requests have been merged
  * 54 reported bugs have been fixed
- Added pkgconfig(glu) Requires to devel package, as per .pc file
- Make devel package provides also devel-static one
- Drop assume-Sphinx-is-there.diff, and add improve-sphinx-search.diff,
  for properly finding sphinx with alphabetic chars in version
* Sun Nov 10 2013 tittiatcoke@gmail.com
- Add patch assume-Sphinx-is-there.diff to fix building with
  Sphinx versions that have alphanumeric characters in the version
  (Only for factory builds at the moment)
* Sun Jul 14 2013 asterios.dramis@gmail.com
- Use eigen3 instead of eigen2 as build requirement for openSUSE > 12.3.
- Enable compilation with libucil and libunicap.
- Removed dos2unix build requirement (not needed anymore).
* Fri Jul 12 2013 koprok@nand.bg
- Update to OpenCV 2.4.6.1
  More info at:
  http://opencv.org/opencv-2-4-6-is-out.html
  The brief list of changes:
  * added video file i/o Windows RT and sample application using
    camera, enabled parallelization with TBB or MS Concurrency
  * added CUDA 5.5 support for desktop and ARM systems
  * added Qt 5 support
  * added many new OpenCL algorithms ports, included OpenCL binaries
    into the Windows superpack
  * iOS build scripts (together with Android ones) moved to
    ‘opencv/platforms’ directory
  * added functions for UIImage <-> cv::Mat conversion
  * correct front/back camera selection in Android app framework
  * added Linaro NDK support and fixes for MIPS to Android CMake
    toolchain
  * stability has been improved by a lot, numerous bug-fixes across
    all the library
* Wed Jun 26 2013 crrodriguez@opensuse.org
- build with LFS_CFLAGS in 32 bit archs.
* Fri May 10 2013 hrvoje.senjan@gmail.com
- Disable SSE3 for all architectures (bnc#814333)
* Thu May  9 2013 hrvoje.senjan@gmail.com
- Disable SSE(2) on non x86_64 architectures, causes crashing
  kde#276923, bnc#789173
* Thu Apr 11 2013 koprok@nand.bg
- Update to OpenCV 2.4.5
  More info at:
  http://opencv.org/opencv-2-4-5-is-out.html
  The brief list of changes:
  * experimental WinRT support
  * new video super-resolution module
  * CLAHE (adaptive histogram equalization) algorithm on both CPU
    and GPU
  * further improvements and extensions in ocl module
    (stereo block matching and belief propagation have been added,
    fixed crashes on Intel HD4000)
  * Visual Studio 2012 cv::Mat visualizer plugin debugger tutorial
    from Microsoft Research
  * OpenCV4Android SDK improvements
    (NDK r8e support, native activity sample using OpenCV Manager,
    bug-fixes)
  * ~25 reported problems have been resolved since 2.4.4, ~78 pull
    requests have been merged, thanks everybody who participated!
* Tue Mar  5 2013 koprok@nand.bg
- Update to OpenCV 2.4.4
  More info at:
  http://opencv.org/opencv-2-4-4-is-out.html
  The brief list of changes:
  * OpenCV Java bindings are ported from Android to desktop Java!
    Actually any JVM language will work, see Tutorial for details,
    and Java or Scala code samples.
  * Android application framework, samples, tutorials, and OpenCV
    Manager are improved.
  * Optimizations for the new NVIDIA Kepler architecture, CARMA
    platform support and other new optimizations in CUDA.
  * OpenCL module now builds successfully with various SDKs (from
    AMD, NVIDIA, Intel and Apple) and runs well on different GPUs
    (AMD, NVidia, Intel HD4000). A lot of new functionality has been
    added, tons of bugs fixed, performance of many functions has
    been significantly improved.
  * 100+ reported problems have been resolved since 2.4.3, thanks
    everybody who participated!
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Drop the buildrequire for libxine
* Wed Nov 28 2012 koprok@nand.bg
- Update to OpenCV 2.4.3
  More info at:
  http://opencv.org/opencv-2-4-3-released.html
  The nicely formatted changelog can be seen here:
  http://code.opencv.org/projects/opencv/wiki/ChangeLog;
  here are the highlights:
  * A lot of good stuff from the Google Summer of Code 2012 has been
    integrated; this was a very productive summer!
  * Significantly improved and optimized Android and iOS ports.
  * Greatly extended GPU (i.e. CUDA-based) module.
  * The brand new ocl (OpenCL-based) module that unleashes GPU power
    also for AMD and Intel GPU users. It’s not included into the
    binary package, since there are different SDKs, and it’s not
    turned on by default. You need to run CMake and turn on
    “WITH_OPENCL”. Also, please note that this is very first version
    of the module, so it may be not very stable and not very
    functional.
  * Much better performance on many-core systems out of the box. You
    do not need TBB anymore on MacOSX, iOS and Windows. BTW, the
    binary package for Windows is now built without TBB support.
    Libraries and DLLs for Visual Studio 2010 use the Concurrency
    framework.
  * About 130 bugs have been fixed since 2.4.2.
  * Since 2.4.3rc we fixed several more problems, in particular some
    compile problems with iOS 6 SDK.
* Tue Sep 18 2012 coolo@suse.com
- buildrequire glu
* Thu Jul  5 2012 koprok@nand.bg
- Update to OpenCV 2.4.2
  More info at:
  http://code.opencv.org/projects/opencv/wiki/ChangeLog
- Drop opencv-datadir.patch to comply with upstream directory layout
* Fri Jun  8 2012 koprok@nand.bg
- Update to OpenCV 2.4.1
  More info at:
  http://code.opencv.org/projects/opencv/wiki/ChangeLog
* Tue May 15 2012 koprok@nand.bg
- Update to OpenCV 2.4.0
  More info at:
  http://code.opencv.org/projects/opencv/wiki/ChangeLog
* Sat Mar 17 2012 dimstar@opensuse.org
- Add opencv-gcc47.patch: Fix build with gcc 4.7.
* Tue Jan 10 2012 crrodriguez@opensuse.org
- Use Explicit Buildrequires on several needed libraries
  future dependency cleanups may/will cause build to fail otherwise.
* Sat Dec 31 2011 idonmez@suse.com
- Add upstream r6881 to fix clang compatibility
* Tue Oct 18 2011 coolo@suse.com
- uncomment libraries not in 12.1 for now
* Fri Oct  7 2011 toddrme2178@gmail.com
- Changed groups (fix for RPMLINT warning)
- Added check for duplicate files (fix for RPMLINT warning)
- Added py_requires macros and python-base dependencies (fix for RPMLINT warning)
- Escaped macros (fix for RPMLINT warning)
- Fixed end-of-line encoding problems (fix for RPMLINT warning)
- Added libeigen2-devel buildrequires
- Added libunicap and libucil buildrequires (libunicap supports requires libucil)
- Cleaned up spec file formatting
* Tue Aug 23 2011 koprok@nand.bg
- Dropped opencv-2.3-ffmpeg.patch, applied upstream
* Tue Aug 23 2011 koprok@nand.bg
- Revive opencv-2.3-ffmpeg.patch, needs rebase
- Tag all patches according to openSUSE packaging guidelines
* Tue Aug 23 2011 koprok@nand.bg
- Removed opencv-2.3-cmake.patch, old cmake cannot be used any more.
- Python bindings cannot be built without NumPy any more.
* Fri Aug 19 2011 koprok@nand.bg
- Update to OpenCV 2.3.1
* Wed Aug 17 2011 reddwarf@opensuse.org
- Update and readd opencv-2.3-underlinking.patch since it is still
  necessary.
* Wed Aug 17 2011 reddwarf@opensuse.org
- Fix support for new ffmpeg versions
* Sat Aug 13 2011 koprok@nand.bg
- Removed unnecessary patches
- Enable Python NumPy support on openSUSE 11.2
- Build Qt instead of Gtk GUI
- Fix cmake files for openSUSE 11.1
- No GStreamer support on openSUSE 11.1
* Fri Aug 12 2011 koprok@nand.bg
- Update to OpenCV 2.3.0.
  More info at:
  http://opencv.willowgarage.com/wiki/OpenCV%%20Change%%20Logs
* Tue Aug  2 2011 koprok@nand.bg
- Fix build on openSUSE 11.2
* Wed Jul  6 2011 idonmez@novell.com
- Add opencv-v4l-2.6.38.patch: use the new libv4l2 interface
* Mon Dec 27 2010 koprok@nand.bg
- Enable Python NumPy support
- SWIG is not required any more
- Enable OpenEXR support
* Thu Dec 23 2010 koprok@nand.bg
- Update to OpenCV 2.2.0.
  More info at:
  http://opencv.willowgarage.com/wiki/OpenCV%%20Change%%20Logs
* Sun Dec 12 2010 cristian.rodriguez@opensuse.org
- Use system zlib, oh, and do not export ZLIB symbols to
  other applications, clashes ensued.
* Thu Nov 11 2010 dmueller@suse.de
- fix build with gcc 4.6
* Fri Oct  8 2010 reddwarf@opensuse.org
- add -underlinking patch
* Thu Apr 22 2010 koprok@nand.bg
- devel package renamed to opencv-devel, so that switching between
  OBS and packman opencv packages is easier
* Mon Apr 19 2010 koprok@nand.bg
- fix gstreamer support
- fix xine support
- fix some rpmlint warnings
- fix shared libraries permissions
* Sat Apr 17 2010 koprok@nand.bg
- Do not waste resources building the tests as we do not run them
* Fri Apr 16 2010 koprok@nand.bg
- Do not disable SSE,SSE2,etc. According to OpenCV changelog,
  it should be safe to leave these enabled.
* Thu Apr 15 2010 koprok@nand.bg
- fix build on openSUSE 11.0
* Tue Apr 13 2010 koprok@nand.bg
- Update to OpenCV 2.1.0:
  * The whole OpenCV is now using exceptions instead of the old
    libc-style mechanism
  * Experimental "static" OpenCV configuration in CMake was
    contributed by Jose Luis Blanco.
    Pass "BUILD_SHARED_LIBS=OFF" to CMake to build OpenCV statically.
  * new improved version of one-way descriptor is added
  * User can now control the image areas visible after the stereo
    rectification
  * Fullscreen has been added (thanks to Yannick Verdie).
  * Further info at:
    http://opencv.willowgarage.com/wiki/OpenCV%%20Change%%20Logs
* Wed Apr  7 2010 coolo@novell.com
- fix build with libpng14
* Thu Mar 18 2010 coolo@novell.com
- small spec file cleanup
* Sat Jan 16 2010 tittiatcoke@gmail.com
- Moved to the KDE repositories to enable inclusion in kipi-plugins
* Fri Oct  9 2009 cmorve69@yahoo.es
- Initial package
